from setuptools import setup, find_packages

setup(
    name="searchbot",
    version="1.0.4",
    author="xialeistudio",
    author_email="xialeistudio@gmail.com",
    description="An AI-powered information retrieval assistant helps users answer questions based on provided context. ",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/xialeistudio/SearchBot",
    package_dir={'': 'src'},
    packages=['searchbot'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_requires=[
        'annotated-types==0.7.0',
        'anyio==4.4.0',
        'beautifulsoup4==4.12.3',
        'bs4==0.0.2',
        'certifi==2024.7.4',
        'charset-normalizer==3.3.2',
        'distro==1.9.0',
        'exceptiongroup==1.2.2',
        'h11==0.14.0',
        'httpcore==1.0.5',
        'httpx==0.27.0',
        'idna==3.7',
        'jiter==0.5.0',
        'jsonpatch==1.33',
        'jsonpointer==3.0.0',
        'langchain-core==0.2.32',
        'langchain-ollama==0.1.1',
        'langchain-openai==0.1.21',
        'langsmith==0.1.99',
        'ollama==0.3.1',
        'openai==1.40.6',
        'orjson==3.10.7',
        'packaging==24.1',
        'pydantic==2.8.2',
        'pydantic_core==2.20.1',
        'PyYAML==6.0.2',
        'regex==2024.7.24',
        'requests==2.32.3',
        'sniffio==1.3.1',
        'soupsieve==2.6',
        'tenacity==8.5.0',
        'tiktoken==0.7.0',
        'tqdm==4.66.5',
        'typing_extensions==4.12.2',
        'urllib3==2.2.2',
    ],
    entry_points={
        'console_scripts': [
            'search-bot=cli:main',
        ],
    },
)
